AdapterOutput class final

Constructors

AdapterOutput({required String targetId, required String packageId, required String sourceAdapter, required String compatibilityId, required AdapterCompleteness completeness, required List<TopologyNode> nodes, List<Diagnostic> diagnostics = const []})
const

Properties

compatibilityId String
final
completeness AdapterCompleteness
final
diagnostics List<Diagnostic>
final
hashCode int
The hash code for this object.
no setterinherited
nodes List<TopologyNode>
final
packageId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source SourceIdentity
no setter
sourceAdapter String
final
targetId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited