AdapterRequest class final

Constructors

AdapterRequest({required String workspaceRoot, required String targetId, required String packageId, required String packageRoot, List<String> configuredRoots = const [], Map<String, Object?> options = const {}})
const

Properties

configuredRoots List<String>
final
hashCode int
The hash code for this object.
no setterinherited
options Map<String, Object?>
final
packageId String
final
packageRoot String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetId String
final
workspaceRoot String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited