Ed25519ReleaseSigner class

Deterministic Ed25519 release-record signer. Private key material is supplied by the caller and is never persisted by this package.

Constructors

Ed25519ReleaseSigner({Ed25519? algorithm})

Properties

algorithm → Ed25519
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sign({required Map<String, Object?> body, required List<int> seed, required String signerId, required String keyId}) Future<Map<String, Object?>>
toString() String
A string representation of this object.
inherited
verify(Map<String, Object?> record, {List<int>? trustedPublicKey}) Future<bool>

Operators

operator ==(Object other) bool
The equality operator.
inherited