EvidenceSlot class

Constructors

EvidenceSlot({required String requirementId, required String evidenceType, required String target, String variant = 'default', required String sourcePackage, required String sourceAdapter})
const

Properties

evidenceType String
final
exactKey String
no setter
hashCode int
The hash code for this object.
no setterinherited
requirementId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceAdapter String
final
sourcePackage String
final
target String
final
variant String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited