ExecutionProfile class final

A named execution profile's scenario selection and extension fields.

Constructors

ExecutionProfile({required String tagExpression, Map<String, Object?> extensions = const {}})
const
ExecutionProfile.fromMap(Map<Object?, Object?> value)
factory

Properties

extensions Map<String, Object?>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tagExpression String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited