ExecutionSourceIdentity class final

Constructors

ExecutionSourceIdentity({required String sourcePackage, required String sourceAdapter, required String sourceCompatibilityId})
const
ExecutionSourceIdentity.fromEnvironment(Map<String, String> environment)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceAdapter String
final
sourceCompatibilityId String
final
sourcePackage String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited