FrameworkAdapter class abstract interface

Properties

compatibilityId String
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

extract(AdapterRequest request) Future<AdapterOutput>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited