GherkinTag class

A tag attached to a Gherkin element.

Constructors

GherkinTag({required String name, required SourceLocation source})
Creates a parsed tag.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Tag name without its leading @.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source SourceLocation
Location of the tag in the source file.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited