HttpRequestSpec class

Logical HTTP request data used by a scenario driver.

Constructors

HttpRequestSpec({required String endpointId, required String method, Object? body, Map<String, String> headers = const {}})
Creates a logical request.
const

Properties

body Object?
Optional request body.
final
endpointId String
Logical endpoint identifier.
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
Request headers.
final
method String
HTTP method.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited