MetadataBlock class

A raw metadata block and its source location.

Constructors

MetadataBlock({required String content, required SourceLocation source})
Creates a metadata block.
const

Properties

content String
YAML content inside the block.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source SourceLocation
Location of the block in the source file.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited