MetadataExtractorResult class

Metadata collected from a workspace's specification files.

Constructors

MetadataExtractorResult({List<ParsedFeature> features = const [], Map<String, Map<String, dynamic>> epics = const {}, Map<String, Map<String, dynamic>> controls = const {}, Map<String, Map<String, dynamic>> registries = const {}, Map<String, Map<String, dynamic>> policies = const {}, List<String> errors = const []})
Creates extracted workspace metadata.
const

Properties

controls Map<String, Map<String, dynamic>>
Control records keyed by identifier.
final
epics Map<String, Map<String, dynamic>>
Epic records keyed by identifier.
final
errors List<String>
Extraction errors.
final
features List<ParsedFeature>
Parsed feature documents.
final
hashCode int
The hash code for this object.
no setterinherited
policies Map<String, Map<String, dynamic>>
Project policy documents keyed by path.
final
registries Map<String, Map<String, dynamic>>
Registry records keyed by identifier.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited