ParseError class
A parser error with its source location.
Constructors
- ParseError({required String message, required SourceLocation source})
-
Creates a parse error.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable error message.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → SourceLocation
-
Location at which the error was detected.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited