instanceCardinality property

String instanceCardinality
final

Runtime multiplicity of widgets represented by this logical binding.

This intentionally differs from cardinality, which is the number of annotated proof providers. The stored vocabulary uses many; the zeroOrMore spelling is accepted as an input alias.

Implementation

final String instanceCardinality;