interaction property
Declares how a Flutter scenario driver uses this binding.
input values are entered, action values are tapped, and output
values are read. It is intentionally nullable for backwards-compatible
parsing of existing feature metadata.
Implementation
final String? interaction;