ParsedControlRef class

A control reference required by a specification.

Constructors

ParsedControlRef({String kind = 'control', required String id, String target = 'backend', String cardinality = 'oneOrMore', List<String>? acceptableAssurance, String variant = 'default', String slot = 'primary'})
Creates a control reference.
const

Properties

acceptableAssurance List<String>?
Acceptable assurance states.
final
cardinality String
Required provider cardinality.
final
hashCode int
The hash code for this object.
no setterinherited
id String
Stable control identifier.
final
kind String
Control reference kind.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slot String
Provider slot.
final
target String
Control execution target.
final
variant String
Provider variant.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited