ParsedEndpoint class
Metadata describing a logical endpoint.
Constructors
Properties
- contract → String?
-
Endpoint contract name.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Stable endpoint identifier.
final
- method → String?
-
HTTP method, when declared.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- target → String
-
Endpoint execution target.
final
- usage → String?
-
Endpoint usage description.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited