ParsedFeature class

A complete parsed Gherkin feature.

Constructors

ParsedFeature({required ParsedMetadata metadata, required List<GherkinTag> tags, required GherkinElement featureElement, required List<ParsedRule> rules, List<GherkinStep> backgroundSteps = const []})
Creates a parsed feature.
const

Properties

backgroundSteps List<GherkinStep>
Feature background steps.
final
featureElement GherkinElement
Parsed feature element.
final
hashCode int
The hash code for this object.
no setterinherited
metadata ParsedMetadata
Feature metadata.
final
rules List<ParsedRule>
Rules declared by the feature.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<GherkinTag>
Feature tags.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited