ParsedRule class

A parsed Gherkin rule and its scenarios.

Constructors

ParsedRule({required ParsedMetadata metadata, required List<GherkinTag> tags, required GherkinElement ruleElement, required List<GherkinScenario> scenarios, List<GherkinStep> backgroundSteps = const []})
Creates a parsed rule.
const

Properties

backgroundSteps List<GherkinStep>
Rule background steps.
final
hashCode int
The hash code for this object.
no setterinherited
metadata ParsedMetadata
Rule metadata.
final
ruleElement GherkinElement
Parsed rule element.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scenarios List<GherkinScenario>
Scenarios owned by the rule.
final
tags List<GherkinTag>
Rule tags.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited