RiskAcceptanceVerificationResult class final
Constructors
-
RiskAcceptanceVerificationResult({required bool valid, bool authenticated = false, List<
RiskAcceptanceDiagnostic> diagnostics = const []}) -
const
Properties
- authenticated → bool
-
final
-
diagnostics
→ List<
RiskAcceptanceDiagnostic> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- valid → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited