RiskAcceptanceVerifier class final

Validates a consumer risk-acceptance record without treating names in a YAML/JSON file as authenticated approval evidence.

Constructors

RiskAcceptanceVerifier()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
verify(Map<Object?, Object?> record, {RiskAcceptanceRequirements requirements = const RiskAcceptanceRequirements(), String? expectedCommit, String? expectedRelease, DateTime? now, RiskAcceptanceApprovalVerifier? approvalVerifier}) RiskAcceptanceVerificationResult

Operators

operator ==(Object other) bool
The equality operator.
inherited