SignedAttestationVerifier class

Verifies a separately signed external-control attestation.

Constructors

SignedAttestationVerifier({Ed25519? algorithm})

Properties

algorithm → Ed25519
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
verify(Map<String, Object?> record, TrustBundle trust) Future<bool>

Operators

operator ==(Object other) bool
The equality operator.
inherited