SourceIdentity class final

Constructors

SourceIdentity({required String target, required String sourcePackage, required String sourceAdapter, required String compatibilityId})
const

Properties

compatibilityId String
final
hashCode int
The hash code for this object.
no setterinherited
key String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceAdapter String
final
sourcePackage String
final
target String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited