SourceLocation class

Source coordinates for a parsed element.

Constructors

SourceLocation({required String file, required int line, int column = 0, int endLine = 0, int endColumn = 0})
Creates a source location.
const

Properties

column int
One-based start column, when known.
final
endColumn int
One-based end column, when known.
final
endLine int
One-based end line, when known.
final
file String
Source file path.
final
hashCode int
The hash code for this object.
no setterinherited
line int
One-based start line.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited