TargetIdentity class final

Stable target/package identity used by current extraction and evidence.

Constructors

TargetIdentity({required String id, required String language, required String framework, List<PackageIdentity> packages = const []})
const

Properties

framework String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
language String
final
packages List<PackageIdentity>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited