TrustBundle class

Constructors

TrustBundle(List<TrustKey> keys)
const
TrustBundle.fromJson(Map value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
keys List<TrustKey>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

find(String signerId, String keyId, String usage) TrustKey?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited