TrustKey class

Constructors

TrustKey({required String signerId, required String keyId, required String algorithm, required List<int> publicKey, required String fingerprint, required Set<String> usages, required String status})
const
TrustKey.fromJson(Map value)
factory

Properties

active bool
no setter
algorithm String
final
fingerprint String
final
hashCode int
The hash code for this object.
no setterinherited
keyId String
final
publicKey List<int>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signerId String
final
status String
final
usages Set<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited