ZukeConfig class
Workspace configuration loaded from zuke.yaml.
Constructors
-
ZukeConfig({int schemaVersion = 3, String? root, List<
String> featurePatterns = const ['specs/features/**/*.feature'], List<String> epicPatterns = const ['specs/epics/**/*.yaml'], List<String> controlPatterns = const ['specs/controls/**/*.yaml'], List<String> registryPatterns = const ['specs/registry/**/*.yaml'], String? projectPolicy, String? preset, List<String> profilePatterns = const [], Map<String, dynamic> targetsConfig = const {}, String? contractOutput, String? contractExport, String? evidenceOutput, String? trustBundle, Map<String, dynamic> executionConfig = const {}, List<WorkspaceRunner> workspaceRunners = const [], Map<String, List< targetPackages = const {}, Map<Map< >String, dynamic> >String, WorkspaceTarget> workspaceTargets = const {}, Map<String, String> targetFrameworks = const {}, Map<String, String> evidenceTypes = const {}, String? lockDirectory, List<String> lockProfiles = const [], Map<String, dynamic> coverageConfig = const {}}) -
Creates workspace configuration.
const
Properties
- contractExport → String?
-
Generated contract export path.
final
- contractOutput → String?
-
Generated contract output path.
final
-
controlPatterns
→ List<
String> -
Control input glob patterns.
final
-
coverageConfig
→ Map<
String, dynamic> -
Independent product coverage policy configuration.
final
-
epicPatterns
→ List<
String> -
Epic input glob patterns.
final
- evidenceOutput → String?
-
Evidence output path.
final
-
evidenceTypes
→ Map<
String, String> -
Current registered evidence types and their satisfaction modes.
final
-
executionConfig
→ Map<
String, dynamic> -
Runner execution configuration.
final
-
featurePatterns
→ List<
String> -
Feature input glob patterns.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lockDirectory → String?
-
V3 lock directory and official profile names.
final
-
lockProfiles
→ List<
String> -
final
- preset → String?
-
Named policy preset.
final
-
profilePatterns
→ List<
String> -
Profile selection patterns.
final
- projectPolicy → String?
-
Project policy path.
final
-
registryPatterns
→ List<
String> -
Registry input glob patterns.
final
- root → String?
-
Workspace root override.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schemaVersion → int
-
Configuration schema. Current consumers should use schema 3.
final
-
targetFrameworks
→ Map<
String, String> -
Current framework selection grouped by target.
final
-
targetPackages
→ Map<
String, List< Map< >String, dynamic> > -
V3 stable package identities grouped by target.
final
-
targetsConfig
→ Map<
String, dynamic> -
Target-specific configuration.
final
- trustBundle → String?
-
Trust bundle path.
final
-
workspaceRunners
→ List<
WorkspaceRunner> -
Typed runner identities for execution and source publication.
final
-
workspaceTargets
→ Map<
String, WorkspaceTarget> -
Typed target/package identities for execution and source publication.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromYaml(
String yamlContent, {String? root}) → ZukeConfig -
Parses
yamlContentinto workspace configuration.