ControlId extension type

A canonical governed control identifier.

This is an extension type so generated constant control sets remain valid compile-time Dart values while retaining the distinct typed API.

on

Constructors

ControlId(String value)
const
ControlId.parse(String value)
factory

Properties

value String
final

Methods

compareTo(ControlId other) int

Static Methods

tryParse(String value) ControlId?