ControlProviderKind enum

Roles that a control provider can play in an application topology.

Inheritance
Available extensions

Values

applicationValidator → const ControlProviderKind

Application-level validation.

const ControlProviderKind('application-validator')
requestValidator → const ControlProviderKind

Request validation.

const ControlProviderKind('request-validator')
requestMiddleware → const ControlProviderKind

Request middleware.

const ControlProviderKind('request-middleware')
publicErrorMapper → const ControlProviderKind

Public error mapping.

const ControlProviderKind('public-error-mapper')
errorInterceptor → const ControlProviderKind

Error interception.

const ControlProviderKind('error-interceptor')
gatewayPolicy → const ControlProviderKind

Gateway policy enforcement.

const ControlProviderKind('gateway-policy')
loggingInterceptor → const ControlProviderKind

Logging interception.

const ControlProviderKind('logging-interceptor')
structuredLogger → const ControlProviderKind

Structured logging.

const ControlProviderKind('structured-logger')
telemetryProcessor → const ControlProviderKind

Telemetry processing.

const ControlProviderKind('telemetry-processor')
semanticsProvider → const ControlProviderKind

Semantics provision.

const ControlProviderKind('semantics-provider')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
Stable serialized provider role.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(String v) ControlProviderKind
Resolves a provider role from its serialized value.

Constants

values → const List<ControlProviderKind>
A constant List of the values in this enum, in order of their declaration.