ImplementsRequirement class

Associates a declaration with one or more governed backend requirements.

Constructors

ImplementsRequirement(List<String> requirementIds, {String target = 'backend', String variant = 'default', String slot = 'primary'})
Creates implementation metadata for requirementIds.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
requirementIds List<String>
Requirement identifiers implemented by the declaration.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slot String
Binding slot occupied by the implementation.
final
target String
Execution target for the implementation.
final
variant String
Variant name used when resolving the implementation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited