VerifiesRequirement class

Associates a test declaration with requirement and evidence identifiers.

Constructors

VerifiesRequirement(List<String> requirementIds, {String? evidenceType, String? target, String variant = 'default', List<String> scenarioIds = const [], List<String> controlIds = const []})
Creates verification metadata for requirementIds.
const

Properties

controlIds List<String>
Control identifiers covered by the verification.
final
evidenceType String?
Evidence kind emitted by the verification.
final
hashCode int
The hash code for this object.
no setterinherited
requirementIds List<String>
Requirement identifiers verified by the declaration.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scenarioIds List<String>
Scenario identifiers covered by the verification.
final
target String?
Target platform or runtime for the verification.
final
variant String
Variant name used when resolving the verification.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited