ZukeScenarioContract class abstract interface

A generated, stable reference to one governed Gherkin scenario.

Properties

controlIds Set<ControlId>
Effective direct and security-profile controls for this scenario's rule.
no setter
hashCode int
The hash code for this object.
no setterinherited
id ScenarioId
Stable SCN-* identifier.
no setter
requirementId RuleId
Stable RULE-* identifier that owns this scenario.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
Human-readable Gherkin scenario title.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited