HttpDriverFactory<W extends ScenarioWorld> class abstract

HTTP projects implement this with their logical endpoint registry and fixture lifecycle. The runner only depends on the world contract.

Inheritance

Constructors

HttpDriverFactory()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create() Future<W>
inherited
dispose(W world) Future<void>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited