StepDataTable class final

A Gherkin step data table.

Constructors

StepDataTable(List<List<String>> rows)
Creates a data table.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
rows List<List<String>>
Table rows in source order.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

asKeyValueMap() Map<String, String>
Converts two-column rows into a key-value map.
asList() List<String>
Flattens all cells into a list.
asLists() List<List<String>>
Returns immutable table rows.
asMaps() List<Map<String, String>>
Converts rows after the header into maps.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited