StepDefinition<W extends ScenarioWorld> class

Constructors

StepDefinition({required RegExp pattern, required StepAction<W> action, int priority = 100, StepTier tier = StepTier.project, String target = 'generic'})
const
StepDefinition.cucumber({required CucumberExpression expression, required TransformedStepAction<W> action, int priority = 100, StepTier tier = StepTier.project, String target = 'generic'})
factory

Properties

action StepAction<W>
final
hashCode int
The hash code for this object.
no setterinherited
pattern RegExp
final
priority int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target String
final
tier StepTier
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited