Diagnostic class final
Constructors
-
Diagnostic({required String code, required String stage, required DiagnosticSeverity severity, DiagnosticOwner owner = DiagnosticOwner.unknown, required String message, String remediation = '', String? profile, String? runnerId, Map<
String, String> context = const {}}) -
const
-
Diagnostic.fromJson(Map<
Object?, Object?> json) -
factory
Properties
- code → String
-
final
-
context
→ Map<
String, String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
final
- owner → DiagnosticOwner
-
final
- profile → String?
-
final
- remediation → String
-
final
- runnerId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- severity → DiagnosticSeverity
-
final
- stage → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited