EvidenceRequirement class final

Inheritance

Constructors

EvidenceRequirement({required String requirementId, required String evidenceType, required String target, String variant = 'default', required String sourcePackage, required String sourceAdapter, String? controlId})
const

Properties

controlId String?
final
evidenceType String
finalinherited
exactKey String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
requirementId String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceAdapter String
finalinherited
sourcePackage String
finalinherited
target String
finalinherited
variant String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited