GherkinExamples class
An Examples table attached to a scenario outline.
Constructors
-
GherkinExamples({required String title, List<
GherkinTag> tags = const [], required List<String> headers, required List<List< rows, required SourceLocation source})String> > -
Creates an Examples block.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ List<
String> -
Column headers.
final
-
rows
→ List<
List< String> > -
Example data rows.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → SourceLocation
-
Examples source location.
final
-
Examples tags.
final
- title → String
-
Examples block title.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited