GherkinParseResult class
Result of parsing one feature document.
Constructors
-
GherkinParseResult({List<
ParsedFeature> features = const [], List<ParseError> errors = const []}) -
Creates a parse result.
const
Properties
-
errors
→ List<
ParseError> -
Errors encountered while parsing.
final
-
features
→ List<
ParsedFeature> -
Features parsed from the document.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited