GherkinStep class
One executable step in a Gherkin scenario.
Constructors
Properties
- docString → String?
-
Attached doc string content.
final
- docStringIndent → int
-
Indentation of the doc string.
final
- docStringMediaType → String?
-
Media type declared for docString.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inheritedKeyword → String
-
Keyword inherited from a preceding
AndorButstep.final - keyword → String
-
Step keyword, such as
GivenorWhen.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → SourceLocation
-
Step source location.
final
-
table
→ List<
List< String> > -
Parsed data table rows.
final
- text → String
-
Step text without its keyword.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited