JsonHttpDriver class
Project-owned HTTP driver primitive. Endpoint IDs are resolved through the generated contract map; features never carry environment URLs.
- Inheritance
Constructors
-
JsonHttpDriver({required Uri baseUri, required Map<
String, String> endpoints, HttpClient? client}) - Creates an HTTP driver.
Properties
- baseUri → Uri
-
Base URI used for logical endpoint requests.
final
- client → HttpClient
-
Client used to make requests.
final
-
endpoints
→ Map<
String, String> -
Map from logical endpoint ID to relative path.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
create(
) → Future< MapScenarioWorld> -
override
-
dispose(
MapScenarioWorld world) → Future< void> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
request(
MapScenarioWorld world, HttpRequestSpec request) → Future< HttpResponseSpec> -
Executes a logical request.
override
-
resetFixtures(
MapScenarioWorld world) → Future< void> -
Resets project fixtures for the next scenario.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited