ParsedBinding class
Metadata describing a generated UI binding.
Constructors
Properties
- cardinality → String
-
Provider cardinality.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Stable binding identifier.
final
- instanceCardinality → String
-
Runtime multiplicity of widgets represented by this logical binding.
final
- interaction → String?
-
Declares how a Flutter scenario driver uses this binding.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slot → String
-
Binding slot selected by the binding.
final
- target → String
-
Binding execution target.
final
- variant → String
-
Variant selected by the binding.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited