ParsedMetadata class
Metadata extracted from a # spec-begin block.
Constructors
-
ParsedMetadata({String? schemaVersion, String? id, String? epic, String? owner, String? status, List<
String> ? targets, List<String> ? pbis, List<ParsedBinding> ? bindings, List<ParsedEndpoint> ? endpoints, List<String> ? events, List<String> ? featureFlags, List<ParsedPerformance> ? performance, List<ParsedControlRef> ? requires, List<String> ? requiredEvidence, List<Map< ? evidenceRequirements, String? securityProfile, Map<String, String> >String, Object?> extensions = const {}, List<String> errors = const [], required SourceLocation source}) -
Creates parsed metadata with
sourceas its origin.const
Properties
-
bindings
→ List<
ParsedBinding> ? -
UI binding metadata.
final
-
endpoints
→ List<
ParsedEndpoint> ? -
Logical endpoint metadata.
final
- epic → String?
-
Owning epic identifier.
final
-
errors
→ List<
String> -
Metadata parsing errors.
final
-
events
→ List<
String> ? -
Declared event identifiers.
final
-
evidenceRequirements
→ List<
Map< ?String, String> > -
V3 exact evidence slots. Each map is validated by the proof engine.
final
-
extensions
→ Map<
String, Object?> -
Forward-compatible metadata extensions.
final
-
featureFlags
→ List<
String> ? -
Declared feature flags.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
Governed identifier declared by the block.
final
- owner → String?
-
Owning team or person.
final
-
pbis
→ List<
String> ? -
Product backlog item identifiers.
final
-
performance
→ List<
ParsedPerformance> ? -
Performance thresholds.
final
-
requiredEvidence
→ List<
String> ? -
Required evidence types.
final
-
requires
→ List<
ParsedControlRef> ? -
Referenced controls.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schemaVersion → String?
-
Declared metadata schema version.
final
- securityProfile → String?
-
Security profile name.
final
- source → SourceLocation
-
Source location of the metadata block.
final
- status → String?
-
Lifecycle status.
final
-
targets
→ List<
String> ? -
Declared execution targets.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited