RiskAcceptanceRequirements class final
Consumer-owned approval and compensating-run requirements.
The verifier intentionally receives this separately from the acceptance record. This prevents a record from lowering its own approval threshold or role requirements.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- requiredApprovalCount → int
-
final
-
requiredCompensatingRuns
→ Set<
String> -
final
-
requiredRoles
→ Set<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited