WorkspaceDartToolingConfig class final
Typed Dart tooling configuration. Shape validation for nested sections stays in discovery; this model retains the validated maps plus unknown fields for forward compatibility.
Constructors
-
WorkspaceDartToolingConfig({Map<
String, Object?> extraction = const {}, Map<String, Object?> analyzerPlugin = const {}, Map<String, Object?> buildHooks = const {}, Map<String, Object?> generation = const {}, Map<String, Object?> extensions = const {}}) -
const
-
WorkspaceDartToolingConfig.fromMap(Map<
Object?, Object?> value) -
factory
Properties
-
analyzerPlugin
→ Map<
String, Object?> -
final
-
buildHooks
→ Map<
String, Object?> -
final
-
extensions
→ Map<
String, Object?> -
final
-
extraction
→ Map<
String, Object?> -
final
-
generation
→ Map<
String, Object?> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited