WorkspaceRunner class final
Constructors
-
WorkspaceRunner({required String id, required String target, required String sourcePackage, required String sourceAdapter, required String sourceCompatibilityId, required String runnerCompatibilityId, String? executable, List<
String> args = const [], List<String> evidenceTypes = const []}) -
const
-
WorkspaceRunner.fromMap(Map<
Object?, Object?> value) -
factory
Properties
-
args
→ List<
String> -
final
-
evidenceTypes
→ List<
String> -
final
- executable → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- runnerCompatibilityId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceAdapter → String
-
final
- sourceCompatibilityId → String
-
final
- sourcePackage → String
-
final
- target → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited