releaseSigningDomain top-level constant
String
const releaseSigningDomain
Immutable signing domains. A domain change is a breaking artifact change and must be called out in migration documentation and changelogs.
Implementation
const releaseSigningDomain = 'Zuke behavioral assurance release\u0000';