EnforcementLayer enum
Application layer at which a control is enforced.
Values
- edge → const EnforcementLayer
-
Network or edge layer.
const EnforcementLayer('edge') - infrastructure → const EnforcementLayer
-
Infrastructure layer.
const EnforcementLayer('infrastructure') - application → const EnforcementLayer
-
Application layer.
const EnforcementLayer('application') - presentation → const EnforcementLayer
-
Presentation layer.
const EnforcementLayer('presentation')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
Stable serialized layer name.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
String v) → EnforcementLayer - Resolves a layer from its serialized value.
Constants
-
values
→ const List<
EnforcementLayer> - A constant List of the values in this enum, in order of their declaration.