PresentsRequirement class
Associates a declaration with one or more requirements presented in a UI.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
requirementIds
→ List<
String> -
Requirement identifiers presented by the declaration.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slot → String
-
Binding slot occupied by the presentation.
final
- target → String
-
Presentation target, normally
flutter.final - variant → String
-
Variant name used when resolving the presentation.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited