ProvidesControl class
Declares a runtime provider for one or more governed controls.
Constructors
-
ProvidesControl(List<
String> controlIds, {ControlProviderKind? kind, EnforcementLayer? layer, String target = 'backend', String variant = 'default', String slot = 'primary'}) -
Creates control-provider metadata for
controlIds.const
Properties
-
controlIds
→ List<
String> -
Control identifiers provided by the declaration.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → ControlProviderKind?
-
Provider role, when the control requires a specific role.
final
- layer → EnforcementLayer?
-
Layer at which the provider is enforced.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slot → String
-
Binding slot occupied by the provider.
final
- target → String
-
Execution target for the provider.
final
- variant → String
-
Variant name used when resolving the provider.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited