ZukeBinding class

Associates a UI declaration with a generated Zuke binding identifier.

Constructors

ZukeBinding(String bindingId, {String variant = 'default', String slot = 'primary'})
Creates binding metadata for bindingId.
const

Properties

bindingId String
Generated binding identifier.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slot String
Binding slot occupied by the binding.
final
variant String
Binding variant selected by the application.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited