Generated binding metadata consumed by target-specific runners.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Stable generated binding identifier.
no setter
- instanceCardinality → BindingInstanceCardinality
-
Runtime multiplicity of the binding.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited