ZukeScenarioPattern class sealed
Matches generated scenario contracts without repeating raw IDs.
Constructors
- ZukeScenarioPattern.exact(ScenarioId id)
-
Creates a pattern matching one scenario ID.
factory
- ZukeScenarioPattern.from(Object pattern)
-
Converts a string, regular expression, or pattern to a pattern object.
factory
- ZukeScenarioPattern.glob(String expression)
-
Creates a glob pattern over scenario IDs.
factory
- ZukeScenarioPattern.prefix(String value)
-
Creates a pattern matching a scenario-ID prefix.
factory
- ZukeScenarioPattern.regExp(RegExp expression)
-
Creates a regular-expression pattern over scenario IDs.
factory
- ZukeScenarioPattern.ruleId(String id)
-
Creates a pattern matching scenarios owned by a rule.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
matches(
ZukeScenarioContract contract) → bool -
Returns whether
contractmatches this pattern. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited