StepParameterType<T> class
final
A typed transformation used by generated Gherkin step support.
Constructors
Properties
-
expressions
→ List<
RegExp> -
Regular expressions accepted by the type.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Stable parameter type name.
final
- preferForRegexpMatch → bool
-
Whether this type is preferred for regular-expression matches.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- snippetPriority → int
-
Ordering priority used during snippet generation.
final
-
transform
→ FutureOr<
T> Function(List<String?> captures) -
Converts captured text to a typed value.
final
- useForSnippets → bool
-
Whether this type may be used for snippets.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited